Column and Data Types — SQLAlchemy 1.0 Documentation

Release: 1.0.7 | Release Date: July 20, 2015

# SQLAlchemy 1.0 Documentation

# Column and Data Types

- Column and Data Types
  - Generic Types
  - SQL Standard Types
  - Vendor-Specific Types
- Custom Types
  - Overriding Type Compilation
  - Augmenting Existing Types
  - TypeDecorator Recipes
  - Replacing the Bind/Result Processing of Existing Types
  - Applying SQL-level Bind/Result Processing
  - Redefining and Creating New Operators
  - Creating New Types
- Base Type API